package Sys::Info::Driver::Unknown::Device;
use strict;
use vars qw( $VERSION );

$VERSION = '0.69_01';

1;

__END__

=head1 NAME

Sys::Info::Driver::Unknown::Device - Base class for Unknown device drivers

=head1 SYNOPSIS

    use base qw( Sys::Info::Driver::Unknown::Device );

=head1 DESCRIPTION

Base class for Unknown device drivers.

=head1 METHODS

None.

=head1 AUTHOR

Burak Gürsoy, E<lt>burakE<64>cpan.orgE<gt>

=head1 COPYRIGHT

Copyright 2006-2009 Burak Gürsoy. All rights reserved.

=head1 LICENSE

This library is free software; you can redistribute it and/or modify 
it under the same terms as Perl itself, either Perl version 5.8.8 or, 
at your option, any later version of Perl 5 you may have available.

=cut
